@@ -16,7 +16,7 @@ use base 'Exporter';
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.065_01'; # VERSION
+our $VERSION = '0.065_02'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -86,16 +86,18 @@ sub make_dist_struct {
 sub parse_dist_spec {
     my ($spec) = @_;
 
-    # AUTHOR / Foo-1.2 = Foo~1.0,Bar~2 & Baz~1.1,Nuts~2.3
-    # -------- -------   -------------   ----------------
-    #    |        |             |               |
-    #  auth*    dist         provides       requires*
+    # AUTHOR / Foo-1.2 .tar.gz = Foo~1.0,Bar~2 & Baz~1.1,Nuts~2.3
+    # -------- ------- -------   ------------- ------------------
+    #    |        |       |           |               |
+    #  auth     dist     ext       provides       requires
     #
-    # * means optional (including the delimiter)
-    #   All whitespace is ignored too
+    # author:    optional, defaults to 'LOCAL'
+    # extension: optional, discarded
+    # requires:  optional
+    # All whitespace is ignored
 
     $spec =~ s{\s+}{}g;  # Remove any whitespace
-    $spec =~ m{ ^ (?: ([^/]+) /)? (.+) = ([^&]+) (?: & (.+) )? $ }mx
+    $spec =~ m{ ^ (?: ([^/]+) /)? (.+?) (?: .tar.gz)? = ([^&]+) (?: & (.+) )? $ }mx
         or confess "Could not parse distribution spec: $spec";
 
     my ($author, $dist, $provides, $requires) = ($1, $2, $3, $4);
@@ -168,7 +170,7 @@ Pinto::Tester::Util - Static helper functions for testing
 
 =head1 VERSION
 
-version 0.065_01
+version 0.065_02
 
 =head1 AUTHOR
 
